"""
Curried functions for operating over data sets and applying functions on them.
Includes safe ways for assigning and retrieving mappings, sequences, and objects.
"""
from pythonix.internals.op import filterx, mapx, reducex, attr, item, arg, assign
